@@ -1689,31 +1689,103 @@ def prompt_template_section_prompt(section: Optional[str] = None) -> str:
 #========================================================================================
 
 @mcp.tool()
-def list_connections(limit: int = 20, offset: int = 0, order_by: str = "connection_id") -> Dict[str, Any]:
+def list_connections(limit: int = 20, 
+                    offset: int = 0, 
+                    fetch_all: bool = False,
+                    order_by: str = "connection_id",
+                    id_contains: Optional[str] = None,
+                    conn_type_contains: Optional[str] = None,
+                    description_contains: Optional[str] = None) -> Dict[str, Any]:
     """
-    [Tool Role]: List all connections in the Airflow instance with pagination support.
+    [Tool Role]: List all connections in the Airflow instance with pagination and advanced filtering support.
     
     Args:
         limit: Maximum number of connections to return (default: 20)
+               - For small queries: use default 20
+               - For large environments: use 100-500 to get more connections at once
+               - Maximum recommended: 1000 (to avoid API timeouts)
         offset: Number of connections to skip for pagination (default: 0)
+        fetch_all: If True, fetches ALL connections regardless of limit (default: False)
+                  - Use with caution in large environments
+                  - Automatically handles pagination internally
         order_by: Field to order by (default: "connection_id")
                  Valid values: connection_id, conn_type, host, schema, login
+        id_contains: Filter connections whose connection_id contains this string (case-insensitive)
+                    - Example: "postgres" → only connections with "postgres" in their ID
+        conn_type_contains: Filter connections whose conn_type contains this string (case-insensitive)
+                           - Example: "http" → only HTTP-based connections
+        description_contains: Filter connections whose description contains this string (case-insensitive)
+                             - Example: "prod" → only connections with "prod" in description
     
     Returns:
-        List of connections with their configuration: connections, total_entries, limit, offset
+        List of connections with their configuration: connections, total_entries, limit, offset, applied_filters
     """
-    # Build query parameters
-    params = [f"limit={limit}", f"offset={offset}"]
-    if order_by:
-        params.append(f"order_by={order_by}")
+    if fetch_all:
+        # Fetch all connections with automatic pagination
+        all_connections = []
+        current_offset = 0
+        batch_limit = 100  # Use reasonable batch size
+        
+        while True:
+            params = [f"limit={batch_limit}", f"offset={current_offset}"]
+            if order_by:
+                params.append(f"order_by={order_by}")
+            
+            query_string = "&".join(params)
+            resp = airflow_request("GET", f"/connections?{query_string}")
+            resp.raise_for_status()
+            batch_data = resp.json()
+            
+            batch_connections = batch_data.get("connections", [])
+            if not batch_connections:
+                break
+                
+            all_connections.extend(batch_connections)
+            current_offset += batch_limit
+            
+            # Check if we've gotten all connections
+            if len(batch_connections) < batch_limit:
+                break
+        
+        raw_connections = all_connections
+        total_from_api = len(all_connections)
+    else:
+        # Regular paginated fetch
+        params = [f"limit={limit}", f"offset={offset}"]
+        if order_by:
+            params.append(f"order_by={order_by}")
+        
+        query_string = "&".join(params)
+        resp = airflow_request("GET", f"/connections?{query_string}")
+        resp.raise_for_status()
+        data = resp.json()
+        
+        raw_connections = data.get("connections", [])
+        total_from_api = data.get("total_entries", len(raw_connections))
     
-    query_string = "&".join(params)
-    resp = airflow_request("GET", f"/connections?{query_string}")
-    resp.raise_for_status()
-    data = resp.json()
+    # Apply client-side filtering (since Airflow API doesn't support these filters)
+    filtered_connections = []
+    applied_filters = []
     
-    connections = []
-    for conn in data.get("connections", []):
+    for conn in raw_connections:
+        # Check id_contains filter
+        if id_contains:
+            conn_id = conn.get("connection_id", "").lower()
+            if id_contains.lower() not in conn_id:
+                continue
+        
+        # Check conn_type_contains filter  
+        if conn_type_contains:
+            conn_type = conn.get("conn_type", "").lower()
+            if conn_type_contains.lower() not in conn_type:
+                continue
+        
+        # Check description_contains filter
+        if description_contains:
+            description = conn.get("description", "").lower()
+            if description_contains.lower() not in description:
+                continue
+        
         # Only return safe connection info (exclude sensitive data like passwords)
         conn_info = {
             "connection_id": conn.get("connection_id"),
@@ -1727,26 +1799,49 @@ def list_connections(limit: int = 20, offset: int = 0, order_by: str = "connecti
             "is_extra_encrypted": conn.get("is_extra_encrypted"),
             "extra": conn.get("extra")  # Note: may contain sensitive data
         }
-        connections.append(conn_info)
+        filtered_connections.append(conn_info)
     
-    # Calculate pagination info
-    total_entries = data.get("total_entries", len(connections))
-    returned_count = len(connections)
-    has_more_pages = (offset + limit) < total_entries
-    next_offset = offset + limit if has_more_pages else None
+    # Record applied filters
+    if id_contains:
+        applied_filters.append(f"id_contains='{id_contains}'")
+    if conn_type_contains:
+        applied_filters.append(f"conn_type_contains='{conn_type_contains}'")
+    if description_contains:
+        applied_filters.append(f"description_contains='{description_contains}'")
+    if order_by:
+        applied_filters.append(f"order_by='{order_by}'")
+    
+    # Calculate pagination info for filtered results
+    total_entries = len(filtered_connections)
+    returned_count = len(filtered_connections)
+    
+    if not fetch_all:
+        # Apply pagination to filtered results
+        start_idx = 0  # We already applied offset in API call
+        end_idx = len(filtered_connections)
+        paginated_connections = filtered_connections[start_idx:end_idx]
+        
+        has_more_pages = (offset + limit) < total_from_api
+        next_offset = offset + limit if has_more_pages else None
+    else:
+        paginated_connections = filtered_connections
+        has_more_pages = False
+        next_offset = None
     
     return {
-        "connections": connections,
+        "connections": paginated_connections,
         "total_entries": total_entries,
-        "limit": limit,
-        "offset": offset,
-        "returned_count": returned_count,
+        "total_from_api": total_from_api,
+        "limit": limit if not fetch_all else len(filtered_connections),
+        "offset": offset if not fetch_all else 0,
+        "returned_count": len(paginated_connections),
         "has_more_pages": has_more_pages,
         "next_offset": next_offset,
+        "applied_filters": applied_filters,
         "pagination_info": {
-            "current_page": (offset // limit) + 1 if limit > 0 else 1,
-            "total_pages": ((total_entries - 1) // limit) + 1 if limit > 0 and total_entries > 0 else 1,
-            "remaining_count": max(0, total_entries - (offset + returned_count))
+            "current_page": (offset // limit) + 1 if limit > 0 and not fetch_all else 1,
+            "total_pages": ((total_entries - 1) // limit) + 1 if limit > 0 and total_entries > 0 and not fetch_all else 1,
+            "remaining_count": max(0, total_entries - (offset + returned_count)) if not fetch_all else 0
         }
     }
 
@@ -1791,7 +1886,7 @@ def create_connection(
     host: Optional[str] = None,
     login: Optional[str] = None,
     password: Optional[str] = None,
-    schema: Optional[str] = None,
+    db_schema: Optional[str] = None,
     port: Optional[int] = None,
     extra: Optional[str] = None
 ) -> Dict[str, Any]:
@@ -1805,7 +1900,7 @@ def create_connection(
         host: Host address for the connection
         login: Login/username for authentication
         password: Password for authentication (will be encrypted)
-        schema: Database schema or namespace
+        db_schema: Database schema or namespace
         port: Port number for the connection
         extra: Additional connection parameters as JSON string
     
@@ -1827,7 +1922,7 @@ def create_connection(
         "host": host,
         "login": login,
         "password": password,
-        "schema": schema,
+        "schema": db_schema,
         "port": port,
         "extra": extra
     }
@@ -1863,7 +1958,7 @@ def update_connection(
     host: Optional[str] = None,
     login: Optional[str] = None,
     password: Optional[str] = None,
-    schema: Optional[str] = None,
+    db_schema: Optional[str] = None,
     port: Optional[int] = None,
     extra: Optional[str] = None
 ) -> Dict[str, Any]:
@@ -1877,7 +1972,7 @@ def update_connection(
         host: Host address for the connection
         login: Login/username for authentication
         password: Password for authentication (will be encrypted)
-        schema: Database schema or namespace
+        db_schema: Database schema or namespace
         port: Port number for the connection
         extra: Additional connection parameters as JSON string
     
@@ -1896,7 +1991,7 @@ def update_connection(
         "host": host,
         "login": login,
         "password": password,
-        "schema": schema,
+        "schema": db_schema,
         "port": port,
         "extra": extra
     }
@@ -1950,6 +2045,232 @@ def delete_connection(connection_id: str) -> Dict[str, Any]:
         "message": f"Connection '{connection_id}' has been successfully deleted"
     }
 
+#========================================================================================
+# Configuration Management Functions
+#========================================================================================
+
+@mcp.tool()
+def get_config() -> Dict[str, Any]:
+    """
+    [Tool Role]: Get all configuration sections and options from the Airflow instance.
+    
+    Note: This endpoint is controlled by the 'expose_config' setting in airflow.cfg.
+    Even admin users will get 403 FORBIDDEN if expose_config = False.
+    
+    Returns:
+        Complete Airflow configuration: sections with their options and values
+    """
+    try:
+        resp = airflow_request("GET", "/config")
+        resp.raise_for_status()
+        config_data = resp.json()
+        
+        # Process config data according to Airflow 2.0.0 API structure
+        sections_processed = {}
+        total_sections = 0
+        total_options = 0
+        
+        for section in config_data.get("sections", []):
+            section_name = section.get("name", "")
+            section_options = {}
+            
+            for option in section.get("options", []):
+                option_key = option.get("key", "")
+                option_value = option.get("value", "")
+                
+                # Basic security: mask values that look like passwords or secrets
+                if any(keyword in option_key.lower() for keyword in ['password', 'secret', 'key', 'token']):
+                    if option_value:
+                        option_value = "[SENSITIVE_VALUE_MASKED]"
+                
+                section_options[option_key] = {
+                    "value": option_value,
+                    "key": option_key
+                }
+                total_options += 1
+            
+            sections_processed[section_name] = {
+                "options": section_options,
+                "option_count": len(section_options)
+            }
+            total_sections += 1
+        
+        return {
+            "sections": sections_processed,
+            "total_sections": total_sections,
+            "total_options": total_options,
+            "raw_sections": config_data.get("sections", []),  # Include raw data for reference
+            "note": "Configuration access requires appropriate permissions in Airflow"
+        }
+        
+    except Exception as e:
+        if "403" in str(e) or "FORBIDDEN" in str(e):
+            return {
+                "error": "Configuration access blocked by Airflow settings",
+                "message": "The configuration endpoint is disabled in Airflow.",
+                "airflow_setting": "expose_config = False in airflow.cfg",
+                "solution_steps": [
+                    "1. Edit /opt/airflow/airflow.cfg (or your Airflow config file)",
+                    "2. Find [webserver] section",
+                    "3. Change 'expose_config = False' to 'expose_config = True'",
+                    "4. Or set 'expose_config = non-sensitive-only' for partial access",
+                    "5. Restart Airflow webserver service",
+                    "6. Alternative: Set environment variable AIRFLOW__WEBSERVER__EXPOSE_CONFIG=True"
+                ],
+                "security_note": "expose_config = True shows all configuration values including sensitive data",
+                "status": "403_FORBIDDEN_BY_CONFIG",
+                "admin_note": "Even admin users cannot access config when expose_config = False"
+            }
+        else:
+            return {
+                "error": "Configuration retrieval failed",
+                "message": str(e),
+                "suggestion": "Check Airflow connection and server status"
+            }
+
+@mcp.tool()
+def list_config_sections() -> Dict[str, Any]:
+    """
+    [Tool Role]: List all available configuration sections with summary information.
+    
+    Note: This is a convenience tool that processes the /config endpoint to show section summaries.
+    
+    Returns:
+        List of configuration sections with option counts and section names
+    """
+    try:
+        config_result = get_config()
+        
+        # Check if we got an error response
+        if "error" in config_result:
+            return config_result  # Return the error as-is
+        
+        sections_summary = []
+        for section_name, section_data in config_result.get("sections", {}).items():
+            section_summary = {
+                "section_name": section_name,
+                "option_count": section_data.get("option_count", 0),
+                "sample_options": list(section_data.get("options", {}).keys())[:5]  # First 5 options
+            }
+            sections_summary.append(section_summary)
+        
+        return {
+            "sections": sections_summary,
+            "total_sections": config_result.get("total_sections", 0),
+            "total_options": config_result.get("total_options", 0),
+            "common_sections_info": {
+                "note": "Common sections typically include core, webserver, scheduler, database, logging",
+                "access_requirement": "Configuration access requires appropriate Airflow permissions"
+            }
+        }
+        
+    except Exception as e:
+        return {
+            "error": "Failed to retrieve configuration sections",
+            "message": str(e),
+            "suggestion": "Check Airflow connection and permissions"
+        }
+
+@mcp.tool()
+def get_config_section(section: str) -> Dict[str, Any]:
+    """
+    [Tool Role]: Get all configuration options for a specific section.
+    
+    Note: This tool filters the /config endpoint results by section name,
+    as Airflow 2.0.0 API doesn't support /config/{section} endpoint.
+    
+    Args:
+        section: The configuration section name (e.g., 'core', 'webserver', 'scheduler')
+    
+    Returns:
+        Section configuration options with values (if accessible)
+    """
+    if not section:
+        return {"error": "Section name must not be empty"}
+    
+    try:
+        config_result = get_config()
+        
+        # Check if we got an error response
+        if "error" in config_result:
+            return config_result  # Return the error as-is
+        
+        sections = config_result.get("sections", {})
+        
+        if section not in sections:
+            available_sections = list(sections.keys())
+            return {
+                "error": f"Section '{section}' not found",
+                "available_sections": available_sections,
+                "suggestion": f"Use one of the available sections: {', '.join(available_sections)}"
+            }
+        
+        section_data = sections[section]
+        options = section_data.get("options", {})
+        
+        return {
+            "section": section,
+            "options": options,
+            "total_options": len(options),
+            "option_names": list(options.keys())
+        }
+        
+    except Exception as e:
+        return {
+            "error": f"Failed to retrieve section '{section}'",
+            "message": str(e)
+        }
+
+@mcp.tool()
+def search_config_options(search_term: str) -> Dict[str, Any]:
+    """
+    [Tool Role]: Search for configuration options by key name.
+    
+    Note: Searches within the /config endpoint results for matching option keys.
+    
+    Args:
+        search_term: Text to search for in option keys (case-insensitive)
+    
+    Returns:
+        Matching configuration options across all sections
+    """
+    if not search_term:
+        return {"error": "Search term must not be empty"}
+    
+    try:
+        config_result = get_config()
+        
+        # Check if we got an error response
+        if "error" in config_result:
+            return config_result  # Return the error as-is
+        
+        matches = []
+        search_lower = search_term.lower()
+        
+        for section_name, section_data in config_result.get("sections", {}).items():
+            for option_key, option_data in section_data.get("options", {}).items():
+                if search_lower in option_key.lower():
+                    match = {
+                        "section": section_name,
+                        "option_key": option_key,
+                        "value": option_data.get("value", ""),
+                        "match_type": "key_name"
+                    }
+                    matches.append(match)
+        
+        return {
+            "search_term": search_term,
+            "matches": matches,
+            "total_matches": len(matches),
+            "sections_searched": list(config_result.get("sections", {}).keys())
+        }
+        
+    except Exception as e:
+        return {
+            "error": f"Failed to search configuration options",
+            "message": str(e)
+        }
+
 #========================================================================================
 
 def main(argv: Optional[List[str]] = None):
@@ -1981,14 +2302,15 @@ def main(argv: Optional[List[str]] = None):
     # mcp.run(transport='http', host="0.0.0.0", port=18000)
     # mcp.run(transport="streamable-http", host="0.0.0.0", port=18000)
     
-    # MCP_SERVER_PORT 환경변수가 있으면 streamable-http, 없으면 stdio
-    if os.getenv("MCP_SERVER_PORT"):
-        # MCP_SERVER_PORT 있음 → http transport
-        port = int(os.getenv("PORT", "18000"))
-        logger.info(f"Starting HTTP server on port {port} for smithery.ai")
-        mcp.run(transport="streamable-http", host="0.0.0.0", port=port)
+    # FASTMCP_PORT 환경변수가 있으면 streamable-http, 없으면 stdio
+    if os.getenv("FASTMCP_PORT"):
+        # FASTMCP_PORT 있음 → http transport
+        host = os.getenv("FASTMCP_HOST", "0.0.0.0")
+        port = int(os.getenv("FASTMCP_PORT", "18000"))
+        logger.info(f"Starting HTTP server on {host}:{port} for smithery.ai")
+        mcp.run(transport="streamable-http", host=host, port=port)
     else:
-        # MCP_SERVER_PORT 없음 → stdio transport
+        # FASTMCP_PORT 없음 → stdio transport
         logger.info("Starting stdio transport for local usage")
         mcp.run(transport='stdio')
 
